"""
    test_config.py Copyright © 2015 by Stefan Lehmann

    Test assignment of hooks.

"""
import sys
import pytest

from PyQt5.QtWidgets import QLineEdit, QApplication
from pyqtconfig import ConfigManager
from pyqtconfig.config import _get_QLineEdit, _set_QLineEdit, _event_QLineEdit

app = QApplication(sys.argv)


def test_hook_direct():
    widget = QLineEdit()
    config = ConfigManager()
    assert config._get_hook(widget) == QLineEdit

def test_hook_inherited():
    class MyLineEdit(QLineEdit):
        pass

    widget = MyLineEdit()
    config = ConfigManager()
    assert config._get_hook(widget) == QLineEdit

def test_hook_inherited_direct():
    class MyLineEdit(QLineEdit):
        pass

    widget = MyLineEdit()
    config = ConfigManager()
    config.add_hooks(MyLineEdit, (_get_QLineEdit, _set_QLineEdit, _event_QLineEdit))
    assert config._get_hook(widget) == MyLineEdit

def test_no_hook():
    class MyTestClass:
        pass
    o = MyTestClass()
    config = ConfigManager()
    with pytest.raises(TypeError) as e:
        assert config._get_hook(o)
    assert "No handler-functions available for this" in str(e)


# -*- coding: utf-8 -*-
''' 
This module is a header-like file for pyqtconfig. Handles compatiblity
with both PyQt5 and PySide2.
'''
import sys

if "PyQt5" in sys.modules:
    from PyQt5.QtCore import (QVariant, Qt, QMutex, QMutexLocker, QSettings,
                              QObject, pyqtSignal)
    from PyQt5.QtWidgets import (QComboBox, QCheckBox, QAction,
                                 QActionGroup, QPushButton, QSpinBox,
                                 QDoubleSpinBox, QPlainTextEdit, QLineEdit,
                                 QListWidget, QSlider, QButtonGroup,
                                 QTabWidget, QApplication, QGridLayout,
                                 QTextEdit, QWidget, QMainWindow)

    Signal = pyqtSignal

elif "PySide2" in sys.modules:
    from PySide.QtGui import (QComboBox, QCheckBox, QAction, QMainWindow,
                              QActionGroup, QPushButton, QSpinBox,
                              QDoubleSpinBox, QPlainTextEdit, QLineEdit,
                              QListWidget, QSlider, QButtonGroup, QWidget,
                              QTabWidget, QApplication, QGridLayout, QTextEdit)
    from PySide.QtCore import (Signal, Qt, QMutex, QMutexLocker, QSettings,
                               QObject)
    
    QVariant = None






import sys
import setuptools


setuptools.setup(

    name='pyqtconfig',
    version="0.9.1",
    author='Martin Fitzpatrick',
    author_email='martin.fitzpatrick@gmail.com',
    url='https://github.com/learnpyqt/pyqtconfig',
    description='An API for keeping PyQt widgets in sync with a config dictionary or QSettings object.',
    long_description='pyqtconfig is a simple API for keeping a config dict in sync with PyQt widgets. \
    Updating the widget automagically updates the dict; updating the dict updates the widget. Internal support \
    for both dictionary config, QSettings and config XML import/export. Combo and list boxes also support \
    mapping from display->internal values.',
    packages=setuptools.find_packages(),
    keywords='pyqt desktop gui pyqt5 qt',
    license='GPL',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.4',
)
